==> plasma-sdk-5.8.8.tar.xz: plasma-sdk-5.8.8/plasmate/plugins/savesystemview/kdevsavesystemview.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=Lets you manage your git repository.
Comment[ast]=Déxate xestionar el to repositoriu git.
Comment[ca]=Permet gestionar el vostre repositori git.
Comment[ca@valencia]=Permet gestionar el vostre repositori git.
Comment[da]=Lader dig håndtere dit git-depot.
Comment[de]=Verwaltung von Git-Quelltextarchiven.
Comment[el]=Επιτρέπει τη διαχείριση του αποθετηρίου σας (git).
Comment[en_GB]=Lets you manage your git repository.
Comment[es]=Le permite gestionar su repositorio git.
Comment[et]=Võimaldab hallata oma giti hoidlat.
Comment[eu]=Zure git gordetegia kudeatzen uzten dizu.
Comment[fi]=Mahdollistaa git-varaston hallinnan.
Comment[fr]=Vous permet de gérer votre dépôt git.
Comment[gl]=Permítelle xestionar o seu repositorio Git.
Comment[it]=Consente di gestire il vostro deposito git.
Comment[ko]=git 저장소를 관리할 수 있도록 합니다.
Comment[nl]=Laat u uw git-repository beheren.
Comment[nn]=Let deg styra Git-kodelager.
Comment[pl]=Umożliwia zarządzanie twoimi repozytoriami git.
Comment[pt]=Permite-lhe gerir o seu repositório do Git.
Comment[pt_BR]=Permite-lhe gerenciar seu repositório Git.
Comment[sk]=Nechá vás spravovať váš git repozitár.
Comment[sl]=Omogoči upravljanje s skladiščem git.
Comment[sr]=Омогућава вам управљање гит ризницама.
Comment[sr@ijekavian]=Омогућава вам управљање гит ризницама.
Comment[sr@ijekavianlatin]=Omogućava vam upravljanje git riznicama.
Comment[sr@latin]=Omogućava vam upravljanje git riznicama.
Comment[sv]=Låter dig hantera Git-arkiv.
Comment[uk]=Надає вам змогу керувати вашим сховищем git.
Comment[x-test]=xxLets you manage your git repository.xx
Comment[zh_CN]=管理您的 git 仓库。
Comment[zh_TW]=讓您管理您的 git 主目錄。
Name=Save System View
Name[ca]=Desa la vista del sistema
Name[ca@valencia]=Guarda la vista del sistema
Name[da]=Gem systemvisning
Name[de]=Systemansicht speichern
Name[en_GB]=Save System View
Name[es]=Guardar vista del sistema
Name[et]=Save Systemi vaade
Name[eu]=Gorde sistemaren ikuspegia
Name[fi]=Tallenna järjestelmän näkymä
Name[fr]=Enregistrer la vue système
Name[gl]=Gardar a vista do sistema
Name[it]=Vista sistema di salvataggio
Name[ko]=시스템 보기 저장
Name[nl]=Systeemweergave opslaan
Name[nn]=Lagra systemvising
Name[pl]=Zapisz widok systemu
Name[pt]=Gravar a Área do Sistema
Name[pt_BR]=Salvar a Área do Sistema
Name[sk]=Uložiť systémový pohľad
Name[sl]=Pogled sistema za shranjevanje
Name[sr]=Приказ уписивања система
Name[sr@ijekavian]=Приказ уписивања система
Name[sr@ijekavianlatin]=Prikaz upisivanja sistema
Name[sr@latin]=Prikaz upisivanja sistema
Name[sv]=Spara systemvy
Name[uk]=Збереження вигляду системи
Name[x-test]=xxSave System Viewxx
Name[zh_CN]=保存系统视图
Name[zh_TW]=儲存系統檢視
GenericName=Save System View
GenericName[ca]=Desa la vista del sistema
GenericName[ca@valencia]=Guarda la vista del sistema
GenericName[da]=Gem systemvisning
GenericName[de]=Systemansicht speichern
GenericName[en_GB]=Save System View
GenericName[es]=Guardar vista del sistema
GenericName[et]=Save Systemi vaade
GenericName[eu]=Gorde sistemaren ikuspegia
GenericName[fi]=Tallenna järjestelmän näkymä
GenericName[fr]=Enregistrer la vue système
GenericName[gl]=Gardar a vista do sistema
GenericName[it]=Vista sistema di salvataggio
GenericName[ko]=시스템 보기 저장
GenericName[nl]=Systeemweergave opslaan
GenericName[nn]=Lagra systemvising
GenericName[pl]=Zapisz widok systemu
GenericName[pt]=Gravar a Área do Sistema
GenericName[pt_BR]=Salvar a Área do Sistema
GenericName[sk]=Uložiť systémový pohľad
GenericName[sl]=Pogled sistema za shranjevanje
GenericName[sr]=Приказ уписивања система
GenericName[sr@ijekavian]=Приказ уписивања система
GenericName[sr@ijekavianlatin]=Prikaz upisivanja sistema
GenericName[sr@latin]=Prikaz upisivanja sistema
GenericName[sv]=Spara systemvy
GenericName[uk]=Зберегти вигляд системи
GenericName[x-test]=xxSave System Viewxx
GenericName[zh_CN]=保存系统视图
GenericName[zh_TW]=儲存系統檢視
Icon=plasmagik
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevsavesystemview
X-KDE-PluginInfo-Name=KDevSaveSystemView
X-KDE-PluginInfo-Author=Giorgos Tsiapaliokas
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-Category=Core
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI

==> plasma-sdk-5.8.95.tar.xz: plasma-sdk-5.8.95/plasmate/plugins/savesystemview/kdevsavesystemview.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=Lets you manage your git repository.
Comment[ca]=Permet gestionar el vostre repositori git.
Comment[ca@valencia]=Permet gestionar el vostre repositori git.
Comment[da]=Lader dig håndtere dit git-depot.
Comment[de]=Verwaltung von Git-Quelltextarchiven.
Comment[el]=Επιτρέπει τη διαχείριση του αποθετηρίου σας (git).
Comment[en_GB]=Lets you manage your git repository.
Comment[es]=Le permite gestionar su repositorio git.
Comment[et]=Võimaldab hallata oma giti hoidlat.
Comment[fi]=Mahdollistaa git-varaston hallinnan.
Comment[fr]=Vous permet de gérer votre dépôt git.
Comment[gl]=Permítelle xestionar o seu repositorio Git.
Comment[it]=Consente di gestire il vostro deposito git.
Comment[ko]=git 저장소를 관리할 수 있도록 합니다.
Comment[nl]=Laat u uw git-repository beheren.
Comment[nn]=Let deg styra Git-kodelager.
Comment[pl]=Umożliwia zarządzanie twoimi repozytoriami git.
Comment[pt]=Permite-lhe gerir o seu repositório do Git.
Comment[pt_BR]=Permite-lhe gerenciar seu repositório Git.
Comment[sk]=Nechá vás spravovať váš git repozitár.
Comment[sl]=Omogoči upravljanje s skladiščem git.
Comment[sr]=Омогућава вам управљање гит ризницама.
Comment[sr@ijekavian]=Омогућава вам управљање гит ризницама.
Comment[sr@ijekavianlatin]=Omogućava vam upravljanje git riznicama.
Comment[sr@latin]=Omogućava vam upravljanje git riznicama.
Comment[sv]=Låter dig hantera Git-arkiv.
Comment[uk]=Надає вам змогу керувати вашим сховищем git.
Comment[x-test]=xxLets you manage your git repository.xx
Comment[zh_CN]=管理您的 git 仓库。
Comment[zh_TW]=讓您管理您的 git 倉庫。
Name=Save System View
Name[ca]=Desa la vista del sistema
Name[ca@valencia]=Guarda la vista del sistema
Name[da]=Gem systemvisning
Name[de]=Systemansicht speichern
Name[en_GB]=Save System View
Name[es]=Guardar vista del sistema
Name[et]=Save Systemi vaade
Name[fi]=Tallenna järjestelmän näkymä
Name[fr]=Enregistrer la vue système
Name[gl]=Gardar a vista do sistema
Name[it]=Vista sistema di salvataggio
Name[ko]=시스템 보기 저장
Name[nl]=Systeemweergave opslaan
Name[nn]=Lagra systemvising
Name[pl]=Zapisz widok systemu
Name[pt]=Gravar a Área do Sistema
Name[pt_BR]=Salvar a Área do Sistema
Name[sk]=Uložiť systémový pohľad
Name[sl]=Pogled sistema za shranjevanje
Name[sr]=Приказ уписивања система
Name[sr@ijekavian]=Приказ уписивања система
Name[sr@ijekavianlatin]=Prikaz upisivanja sistema
Name[sr@latin]=Prikaz upisivanja sistema
Name[sv]=Spara systemvy
Name[uk]=Збереження вигляду системи
Name[x-test]=xxSave System Viewxx
Name[zh_CN]=保存系统视图
Name[zh_TW]=儲存系統檢視
GenericName=Save System View
GenericName[ca]=Desa la vista del sistema
GenericName[ca@valencia]=Guarda la vista del sistema
GenericName[da]=Gem systemvisning
GenericName[de]=Systemansicht speichern
GenericName[en_GB]=Save System View
GenericName[es]=Guardar vista del sistema
GenericName[et]=Save Systemi vaade
GenericName[fi]=Tallenna järjestelmän näkymä
GenericName[fr]=Enregistrer la vue système
GenericName[gl]=Gardar a vista do sistema
GenericName[it]=Vista sistema di salvataggio
GenericName[ko]=시스템 보기 저장
GenericName[nl]=Systeemweergave opslaan
GenericName[nn]=Lagra systemvising
GenericName[pl]=Zapisz widok systemu
GenericName[pt]=Gravar a Área do Sistema
GenericName[pt_BR]=Salvar a Área do Sistema
GenericName[sk]=Uložiť systémový pohľad
GenericName[sl]=Pogled sistema za shranjevanje
GenericName[sr]=Приказ уписивања система
GenericName[sr@ijekavian]=Приказ уписивања система
GenericName[sr@ijekavianlatin]=Prikaz upisivanja sistema
GenericName[sr@latin]=Prikaz upisivanja sistema
GenericName[sv]=Spara systemvy
GenericName[uk]=Зберегти вигляд системи
GenericName[x-test]=xxSave System Viewxx
GenericName[zh_CN]=保存系统视图
GenericName[zh_TW]=儲存系統檢視
Icon=plasmagik
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevsavesystemview
X-KDE-PluginInfo-Name=KDevSaveSystemView
X-KDE-PluginInfo-Author=Giorgos Tsiapaliokas
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-Category=Core
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI
